# -*- coding: utf-8 -*-

from string import ascii_lowercase, whitespace

def supprimer_faux_retours(event=None):
    '''Supprime les marques de paragraphes situées en milieu de phrase.
    Agit sur le document entier'''
    doc = XSCRIPTCONTEXT.getDocument()
    undo = doc.UndoManager
    undo.enterUndoContext('Supprimer faux retours')
    doc.lockControllers()
    try:
        _supprimer_faux_retours(doc)
        win = doc.CurrentController.ComponentWindow
        win.Toolkit.createMessageBox(win, 0, 1, "", "Ok !").execute()
    finally:
        doc.unlockControllers()
        undo.leaveUndoContext()


def supprimer_faux_retours_selection(event=None):
    '''Supprime les marques de paragraphes situées en milieu de phrase.
    Agit sur la sélection uniquement.'''
    doc = XSCRIPTCONTEXT.getDocument()
    undo = doc.UndoManager
    undo.enterUndoContext('Supprimer faux retours (sélection)')
    doc.lockControllers()
    try:
        for selection in doc.CurrentSelection:
            T = selection.Text
            tcursor = T.createTextCursorByRange(selection)
            tcursor.gotoEndOfSentence(False)
            while tcursor.gotoNextSentence(True):
                if T.compareRegionEnds(tcursor, selection) < 0:
                    break
                if tcursor.String.startswith('\r\n'):
                    s = ' '
                    while s in whitespace:
                        tcursor.goRight(1, True)
                        s = tcursor.String[-1]
                    if s in ascii_lowercase:
                        tcursor.String = ' ' + s
                tcursor.gotoEndOfSentence(False)
            for p in selection.createEnumeration():
                try:
                    if p.supportsService('com.sun.star.text.TextTable'):
                        cellnames = p.CellNames
                        for cellname in cellnames:
                            cell = p.getCellByName(cellname)
                            _supprimer_faux_retours(cell)
                except AttributeError:
                        pass
            for textcontent in selection.createContentEnumeration('com.sun.star.text.TextContent'):
                if textcontent.supportsService('com.sun.star.text.TextFrame'):
                    _supprimer_faux_retours(textcontent)
            win = doc.CurrentController.ComponentWindow
        win.Toolkit.createMessageBox(win, 0, 1, "", "Ok !").execute()
    finally:
        doc.unlockControllers()
        undo.leaveUndoContext()


def _supprimer_faux_retours(container):
    T = container.Text
    tcursor = T.createTextCursor()
    tcursor.gotoEndOfSentence(False)
    while tcursor.gotoNextSentence(True):
        if tcursor.String.startswith('\r\n'):
            s = ' '
            while s in whitespace:
                tcursor.goRight(1, True)
                s = tcursor.String[-1]
            if s in ascii_lowercase:
                tcursor.String = ' ' + s
        tcursor.gotoEndOfSentence(False)
    try:
        for frame in container.TextFrames:
            _supprimer_faux_retours(frame)
    except AttributeError:
        pass
    try:
        for table in container.TextTables:
            cellnames = table.CellNames
            for cellname in cellnames:
                cell = table.getCellByName(cellname)
                _supprimer_faux_retours(cell)
    except AttributeError:
        pass


g_exportedScripts = supprimer_faux_retours, supprimer_faux_retours_selection,